# Secretive

A password generator

# Usage

## Installation

```bash
pip install secretive
```

## Basic Usage

```bash
passwordgen.py "giantas"

# character length of 20
passwordgen.py "giantas" --length 20

passwordgen.py --help
```